@@ -57,7 +57,7 @@ class SignalFourier(SignalComplet):
 
 if __name__ == "__main__":
 
-    s1 = SignalFourier(3, [1,1], [], nom="$s_1$")
+    s1 = SignalFourier(1e3, [1,1], [], nom="$s_1$")
 
     s1.tracer_signal()
 
